@@ -28,11 +28,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QPainter>
 #include <QDebug>
 
-
 AbstractProjectItem::AbstractProjectItem(PROJECTITEMTYPE type, const QString &id, AbstractProjectItem* parent) :
     QObject()
     , m_parent(parent)
     , m_id(id)
+    , m_usage(0)
     , m_clipStatus(StatusReady)
     , m_jobType(AbstractClipJob::NOJOBTYPE)
     , m_jobProgress(0)
@@ -44,7 +44,8 @@ AbstractProjectItem::AbstractProjectItem(PROJECTITEMTYPE type, const QString &id
 AbstractProjectItem::AbstractProjectItem(PROJECTITEMTYPE type, const QDomElement& description, AbstractProjectItem* parent) :
     QObject()
     , m_parent(parent)
-    , m_id(description.attribute("id"))
+    , m_id(description.attribute(QStringLiteral("id")))
+    , m_usage(0)
     , m_clipStatus(StatusReady)
     , m_jobType(AbstractClipJob::NOJOBTYPE)
     , m_jobProgress(0)
@@ -75,6 +76,29 @@ AbstractProjectItem* AbstractProjectItem::parent() const
     return m_parent;
 }
 
+void AbstractProjectItem::setRefCount(uint count)
+{
+    m_usage = count;
+    bin()->emitItemUpdated(this);
+}
+
+uint AbstractProjectItem::refCount() const
+{
+    return m_usage;
+}
+
+void AbstractProjectItem::addRef()
+{
+    m_usage++;
+    bin()->emitItemUpdated(this);
+}
+
+void AbstractProjectItem::removeRef()
+{
+    m_usage--;
+    bin()->emitItemUpdated(this);
+}
+
 const QString &AbstractProjectItem::clipId() const
 {
     return m_id;
@@ -155,10 +179,6 @@ QVariant AbstractProjectItem::data(DataType type) const
     QVariant data;
     QLocale locale;
     switch (type) {
-        case SortRole:
-            if (m_itemType == SubClipItem) data = QVariant(m_duration);
-            else data = QVariant(m_name);
-        break;
         case DataName:
             data = QVariant(m_name);
             break;
@@ -168,12 +188,18 @@ QVariant AbstractProjectItem::data(DataType type) const
 	case DataThumbnail:
             data = QVariant(m_thumbnail);
             break;
+        case DataId:
+            data = QVariant(m_id);
+            break;
 	case DataDuration:
 	    data = QVariant(m_duration);
             break;
         case DataDate:
             data = QVariant(m_date);
             break;
+        case UsageCount:
+            data = QVariant(m_usage);
+            break;
         case ItemTypeRole:
             data = QVariant(m_itemType);
             break;
@@ -192,9 +218,6 @@ QVariant AbstractProjectItem::data(DataType type) const
         case ClipToolTip:
             data = QVariant(getToolTip());
             break;
-        case DataId:
-            data = QVariant(m_id);
-            break;
         default:
             break;
     }
