@@ -454,7 +454,6 @@ public:
     void doMoveFolder(const QString &id, const QString &newParentId);
     void setupGeneratorMenu();
     void startClipJob(const QStringList &params);
-    void droppedUrls(QList <QUrl> urls);
 
     void addClipCut(const QString&id, int in, int out);
     void removeClipCut(const QString&id, int in, int out);
@@ -489,6 +488,9 @@ public:
     void moveEffect(const QString &id, const QList <int> &oldPos, const QList <int> &newPos);
     /** @brief Add an effect to a bin clip. */
     void addEffect(const QString &id, QDomElement &effect);
+    /** @brief Update a bin clip effect. */
+    void updateEffect(const QString &id, QDomElement &effect, int ix, bool refreshStackWidget);
+    void changeEffectState(const QString &id, const QList <int>& indexes, bool disable, bool refreshStack);
     /** @brief Edit an effect settings to a bin clip. */
     void editMasterEffect(ClipController *ctl);
     /** @brief An effect setting was changed, update stack if displayed. */
@@ -529,6 +531,8 @@ public:
     void rebuildProxies();
     /** @brief Return a list of all clips hashes used in this project */
     QStringList getProxyHashList();
+        /** @brief Get info (id, name) of a folder (or the currently selected one)  */
+    const QStringList getFolderInfo(QModelIndex selectedIx = QModelIndex());
 
 private slots:
     void slotAddClip();
@@ -554,7 +558,10 @@ private slots:
     void slotItemDropped(QStringList ids, const QModelIndex &parent);
     void slotItemDropped(const QList<QUrl>&urls, const QModelIndex &parent);
     void slotEffectDropped(QString effect, const QModelIndex &parent);
+    void slotUpdateEffect(QString id, QDomElement oldEffect, QDomElement newEffect, int ix);
+    void slotChangeEffectState(QString id, QList<int> indexes, bool disable);
     void slotItemEdited(QModelIndex,QModelIndex,QVector<int>);
+    void slotAddUrl(QString url, int folderId, QMap <QString, QString> data = QMap <QString, QString>());
     void slotAddUrl(QString url, QMap <QString, QString> data = QMap <QString, QString>());
     void slotPrepareJobsMenu();
     void slotShowJobLog();
@@ -647,6 +654,7 @@ public slots:
     void selectClipById(const QString &id, int frame = -1, const QPoint &zone = QPoint());
     void slotAddClipToProject(QUrl url);
     void doUpdateThumbsProgress(long ms);
+    void droppedUrls(QList <QUrl> urls, const QStringList &folderInfo = QStringList());
 
 protected:
     void contextMenuEvent(QContextMenuEvent *event);
@@ -718,7 +726,6 @@ private:
     /** @brief Indicates whether audio thumbnail creation is running. */
     QFuture<void> m_audioThumbsThread;
     void showClipProperties(ProjectClip *clip, bool forceRefresh = false);
-    const QStringList getFolderInfo(QModelIndex selectedIx = QModelIndex());
     /** @brief Get the QModelIndex value for an item in the Bin. */
     QModelIndex getIndexForId(const QString &id, bool folderWanted) const;
     /** @brief Get a Clip item from its id. */
