@@ -20,6 +20,7 @@
 #include "kdenlivesettingsdialog.h"
 #include "profilesdialog.h"
 #include "encodingprofilesdialog.h"
+#include "project/dialogs/profilewidget.h"
 #include "utils/KoIconUtils.h"
 #include "dialogs/profilesdialog.h"
 #include "kdenlivesettings.h"
@@ -67,12 +68,18 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
 
     // Hide avformat-novalidate trick, causes crash (bug #2205 and #2206)
     m_configMisc.kcfg_projectloading_avformatnovalidate->setVisible(false);
-    
+
     m_configMisc.kcfg_use_exiftool->setEnabled(!QStandardPaths::findExecutable(QStringLiteral("exiftool")).isEmpty());
 
     QWidget *p8 = new QWidget;
     m_configProject.setupUi(p8);
     m_page8 = addPage(p8, i18n("Project Defaults"));
+    QVBoxLayout *vbox = new QVBoxLayout;
+    m_pw = new ProfileWidget(this);
+    vbox->addWidget(m_pw);
+    m_configProject.profile_box->setLayout(vbox);
+    // Select profile
+    m_pw->loadProfile(KdenliveSettings::default_profile().isEmpty() ? KdenliveSettings::current_profile() : KdenliveSettings::default_profile());
     m_page8->setIcon(KoIconUtils::themedIcon(QStringLiteral("project-defaults")));
     connect(m_configProject.kcfg_generateproxy, SIGNAL(toggled(bool)), m_configProject.kcfg_proxyminsize, SLOT(setEnabled(bool)));
     m_configProject.kcfg_proxyminsize->setEnabled(KdenliveSettings::generateproxy());
@@ -114,7 +121,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
 
     QWidget *p4 = new QWidget;
     m_configCapture.setupUi(p4);
-
+    m_configCapture.tabWidget->removeTab(0);
+    m_configCapture.tabWidget->removeTab(2);
 #ifdef USE_V4L
 
     // Video 4 Linux device detection
@@ -216,17 +224,12 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
 
     connect(m_configEnv.kp_image, SIGNAL(clicked()), this, SLOT(slotEditImageApplication()));
     connect(m_configEnv.kp_audio, SIGNAL(clicked()), this, SLOT(slotEditAudioApplication()));
-    connect(m_configEnv.kp_player, SIGNAL(clicked()), this, SLOT(slotEditVideoApplication()));
 
     loadEncodingProfiles();
-    checkProfile();
-
-    slotUpdateDisplay();
 
     connect(m_configSdl.kcfg_audio_driver, SIGNAL(currentIndexChanged(int)), this, SLOT(slotCheckAlsaDriver()));
     connect(m_configSdl.kcfg_audio_backend, SIGNAL(currentIndexChanged(int)), this, SLOT(slotCheckAudioBackend()));
     initDevices();
-    connect(m_configProject.kcfg_profiles_list, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDisplay()));
     connect(m_configCapture.kcfg_grab_capture_type, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateGrabRegionStatus()));
 
     slotUpdateGrabRegionStatus();
@@ -242,39 +245,57 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     }
 
     // decklink profile
+    QAction *act = new QAction(KoIconUtils::themedIcon(QStringLiteral("configure")), i18n("Configure profiles"), this);
+    act->setData(4);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(slotManageEncodingProfile()));
+    m_configCapture.decklink_manageprofile->setDefaultAction(act);
     m_configCapture.decklink_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
-    m_configCapture.decklink_manageprofile->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
     m_configCapture.decklink_parameters->setVisible(false);
     m_configCapture.decklink_parameters->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
     m_configCapture.decklink_parameters->setPlainText(KdenliveSettings::decklink_parameters());
-    connect(m_configCapture.decklink_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
     connect(m_configCapture.kcfg_decklink_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDecklinkProfile()));
     connect(m_configCapture.decklink_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.decklink_parameters, SLOT(setVisible(bool)));
 
     // ffmpeg profile
     m_configCapture.v4l_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
-    m_configCapture.v4l_manageprofile->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
     m_configCapture.v4l_parameters->setVisible(false);
     m_configCapture.v4l_parameters->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
     m_configCapture.v4l_parameters->setPlainText(KdenliveSettings::v4l_parameters());
-    connect(m_configCapture.v4l_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+
+    act = new QAction(KoIconUtils::themedIcon(QStringLiteral("configure")), i18n("Configure profiles"), this);
+    act->setData(2);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(slotManageEncodingProfile()));
+    m_configCapture.v4l_manageprofile->setDefaultAction(act);
     connect(m_configCapture.kcfg_v4l_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateV4lProfile()));
     connect(m_configCapture.v4l_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.v4l_parameters, SLOT(setVisible(bool)));
-    
+
     // screen grab profile
     m_configCapture.grab_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
-    m_configCapture.grab_manageprofile->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
     m_configCapture.grab_parameters->setVisible(false);
     m_configCapture.grab_parameters->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
     m_configCapture.grab_parameters->setPlainText(KdenliveSettings::grab_parameters());
-    connect(m_configCapture.grab_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+    act = new QAction(KoIconUtils::themedIcon(QStringLiteral("configure")), i18n("Configure profiles"), this);
+    act->setData(3);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(slotManageEncodingProfile()));
+    m_configCapture.grab_manageprofile->setDefaultAction(act);
     connect(m_configCapture.kcfg_grab_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateGrabProfile()));
     connect(m_configCapture.grab_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.grab_parameters, SLOT(setVisible(bool)));
 
-    // Project profile management
-    m_configProject.manage_profiles->setIcon(KoIconUtils::themedIcon("configure"));
-    m_configProject.manage_profiles->setToolTip(i18n("Manage Project Profiles"));
-    connect(m_configProject.manage_profiles, SIGNAL(clicked(bool)), this, SLOT(slotEditProfiles()));
+    // Timeline preview
+    act = new QAction(KoIconUtils::themedIcon(QStringLiteral("configure")), i18n("Configure profiles"), this);
+    act->setData(1);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(slotManageEncodingProfile()));
+    m_configProject.preview_manageprofile->setDefaultAction(act);
+    connect(m_configProject.kcfg_preview_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdatePreviewProfile()));
+    connect(m_configProject.preview_showprofileinfo, SIGNAL(clicked(bool)), m_configProject.previewparams, SLOT(setVisible(bool)));
+    m_configProject.previewparams->setVisible(false);
+    m_configProject.previewparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 3);
+    m_configProject.previewparams->setPlainText(KdenliveSettings::previewparams());
+    m_configProject.preview_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
+    m_configProject.preview_showprofileinfo->setToolTip(i18n("Show default timeline preview parameters"));
+    m_configProject.preview_manageprofile->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
+    m_configProject.preview_manageprofile->setToolTip(i18n("Manage timeline preview profiles"));
+    m_configProject.kcfg_preview_profile->setToolTip(i18n("Select default timeline preview profile"));
 
     // proxy profile stuff
     m_configProject.proxy_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
@@ -283,9 +304,14 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_configProject.proxy_manageprofile->setToolTip(i18n("Manage proxy profiles"));
     m_configProject.kcfg_proxy_profile->setToolTip(i18n("Select default proxy profile"));
     m_configProject.proxyparams->setVisible(false);
-    m_configProject.proxyparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
+    m_configProject.proxyparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 3);
     m_configProject.proxyparams->setPlainText(KdenliveSettings::proxyparams());
-    connect(m_configProject.proxy_manageprofile, SIGNAL(clicked(bool)), this, SLOT(slotManageEncodingProfile()));
+
+    act = new QAction(KoIconUtils::themedIcon(QStringLiteral("configure")), i18n("Configure profiles"), this);
+    act->setData(0);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(slotManageEncodingProfile()));
+    m_configProject.proxy_manageprofile->setDefaultAction(act);
+
     connect(m_configProject.proxy_showprofileinfo, SIGNAL(clicked(bool)), m_configProject.proxyparams, SLOT(setVisible(bool)));
     connect(m_configProject.kcfg_proxy_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateProxyProfile()));
 
@@ -294,7 +320,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     slotUpdateV4lProfile(-1);
     slotUpdateGrabProfile(-1);
     slotUpdateDecklinkProfile(-1);
-    
+
     // enable GPU accel only if Movit is found
     m_configSdl.kcfg_gpu_accel->setEnabled(gpuAllowed);
     m_configSdl.kcfg_gpu_accel->setToolTip(i18n("GPU processing needs MLT compiled with Movit and Rtaudio modules"));
@@ -441,28 +467,6 @@ void KdenliveSettingsDialog::slotEnableLibraryFolder()
     m_configEnv.libraryfolderurl->setEnabled(!m_configEnv.kcfg_librarytodefaultfolder->isChecked());
 }
 
-void KdenliveSettingsDialog::checkProfile()
-{
-    m_configProject.kcfg_profiles_list->clear();
-    QMap <QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
-    QMapIterator<QString, QString> i(profilesInfo);
-    while (i.hasNext()) {
-        i.next();
-        m_configProject.kcfg_profiles_list->addItem(i.value(), i.key());
-    }
-
-    if (!KdenliveSettings::default_profile().isEmpty()) {
-        int ix = m_configProject.kcfg_profiles_list->findData(KdenliveSettings::default_profile());
-        if (ix > -1) {
-            m_configProject.kcfg_profiles_list->setCurrentIndex(ix);
-            KdenliveSettings::setProfiles_list(ix);
-        } else {
-            // Error, profile not found
-            qWarning()<<"Project profile not found, disable  editing";
-        }
-    }
-}
-
 void KdenliveSettingsDialog::initDevices()
 {
     // Fill audio drivers
@@ -591,18 +595,6 @@ void KdenliveSettingsDialog::showPage(int page, int option)
     }
 }
 
-void KdenliveSettingsDialog::slotEditVideoApplication()
-{
-    KService::Ptr service;
-    QPointer<KOpenWithDialog> dlg = new KOpenWithDialog(QList<QUrl>(), i18n("Select default video player"), m_configEnv.kcfg_defaultplayerapp->text(), this);
-    if (dlg->exec() == QDialog::Accepted) {
-        service = dlg->service();
-        m_configEnv.kcfg_defaultplayerapp->setText(KRun::binaryName(service->exec(), false));
-    }
-
-    delete dlg;
-}
-
 void KdenliveSettingsDialog::slotEditAudioApplication()
 {
     KService::Ptr service;
@@ -698,8 +690,7 @@ void KdenliveSettingsDialog::updateSettings()
 {
     // Save changes to settings (for example when user pressed "Apply" or "Ok")
     // //qDebug() << "// // // KCONFIG UPDATE called";
-    m_defaultProfile = m_configProject.kcfg_profiles_list->currentText();
-    KdenliveSettings::setDefault_profile(m_defaultPath);
+    KdenliveSettings::setDefault_profile(m_pw->selectedProfile());
 
     bool resetProfile = false;
     bool updateCapturePath = false;
@@ -782,6 +773,12 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setProxyextension(data.section(';', 1, 1));
     }
 
+    // timeline preview
+    data = m_configProject.kcfg_preview_profile->itemData(m_configProject.kcfg_preview_profile->currentIndex()).toString();
+    if (!data.isEmpty() && (data.section(';', 0, 0) != KdenliveSettings::previewparams() || data.section(';', 1, 1) != KdenliveSettings::previewextension())) {
+        KdenliveSettings::setPreviewparams(data.section(';', 0, 0));
+        KdenliveSettings::setPreviewextension(data.section(';', 1, 1));
+    }
 
     if (updateCapturePath) emit updateCaptureFolder();
     if (updateLibrary) emit updateLibraryFolder();
@@ -813,7 +810,7 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setAudiodevicename(QString());
         resetProfile = true;
     }
-    
+
     value = m_configSdl.kcfg_audio_backend->itemData(m_configSdl.kcfg_audio_backend->currentIndex()).toString();
     if (value != KdenliveSettings::audiobackend()) {
         KdenliveSettings::setAudiobackend(value);
@@ -830,6 +827,10 @@ void KdenliveSettingsDialog::updateSettings()
         resetProfile = true;
     }
 
+    if (m_configMisc.kcfg_tabposition->currentIndex() != KdenliveSettings::tabposition()) {
+        KdenliveSettings::setTabposition(m_configMisc.kcfg_tabposition->currentIndex());
+    }
+
     if (m_modified) {
         // The transcoding profiles were modified, save.
         m_modified = false;
@@ -849,7 +850,7 @@ void KdenliveSettingsDialog::updateSettings()
     if (KdenliveSettings::shuttlebuttons() != maps)
         KdenliveSettings::setShuttlebuttons(maps);
 #endif
-    
+
     bool restart = false;
     if (m_configSdl.kcfg_gpu_accel->isChecked() != KdenliveSettings::gpu_accel()) {
 	// GPU setting was changed, we need to restart Kdenlive or everything will be corrupted
@@ -865,22 +866,7 @@ void KdenliveSettingsDialog::updateSettings()
     //KConfigDialog::updateSettings();
     if (resetProfile) emit doResetProfile();
     if (restart) emit restartKdenlive();
-}
-
-void KdenliveSettingsDialog::slotUpdateDisplay()
-{
-    QString currentProfile = m_configProject.kcfg_profiles_list->itemData(m_configProject.kcfg_profiles_list->currentIndex()).toString();
-    QMap< QString, QString > values = ProfilesDialog::getSettingsFromFile(currentProfile);
-    m_configProject.p_size->setText(values.value(QStringLiteral("width")) + 'x' + values.value(QStringLiteral("height")));
-    m_configProject.p_fps->setText(values.value(QStringLiteral("frame_rate_num")) + '/' + values.value(QStringLiteral("frame_rate_den")));
-    m_configProject.p_aspect->setText(values.value(QStringLiteral("sample_aspect_num")) + '/' + values.value(QStringLiteral("sample_aspect_den")));
-    m_configProject.p_display->setText(values.value(QStringLiteral("display_aspect_num")) + '/' + values.value(QStringLiteral("display_aspect_den")));
-    if (values.value(QStringLiteral("progressive")).toInt() == 0)
-        m_configProject.p_progressive->setText(i18n("Interlaced"));
-    else
-        m_configProject.p_progressive->setText(i18n("Progressive"));
-    m_defaultProfile = m_configProject.kcfg_profiles_list->itemText(m_configProject.kcfg_profiles_list->currentIndex());
-    m_defaultPath = currentProfile;
+    emit checkTabPosition();
 }
 
 void KdenliveSettingsDialog::slotCheckAlsaDriver()
@@ -1141,9 +1127,10 @@ void KdenliveSettingsDialog::saveCurrentV4lProfile()
 
 void KdenliveSettingsDialog::slotManageEncodingProfile()
 {
+    QAction *act = qobject_cast<QAction *>(sender());
     int type = 0;
-    if (currentPage() == m_page4) {
-        type = m_configCapture.tabWidget->currentIndex();
+    if (act) {
+        type = act->data().toInt();
     }
     QPointer<EncodingProfilesDialog> d = new EncodingProfilesDialog(type);
     d->exec();
@@ -1168,7 +1155,7 @@ void KdenliveSettingsDialog::loadEncodingProfiles()
     }
     m_configCapture.kcfg_v4l_profile->blockSignals(false);
     if (!currentItem.isEmpty()) m_configCapture.kcfg_v4l_profile->setCurrentIndex(m_configCapture.kcfg_v4l_profile->findText(currentItem));
-    
+
     // Load Screen Grab profiles
     m_configCapture.kcfg_grab_profile->blockSignals(true);
     currentItem = m_configCapture.kcfg_grab_profile->currentText();
@@ -1196,6 +1183,27 @@ void KdenliveSettingsDialog::loadEncodingProfiles()
     }
     m_configCapture.kcfg_decklink_profile->blockSignals(false);
     if (!currentItem.isEmpty()) m_configCapture.kcfg_decklink_profile->setCurrentIndex(m_configCapture.kcfg_decklink_profile->findText(currentItem));
+    
+    // Load Timeline Preview profiles
+    m_configProject.kcfg_preview_profile->blockSignals(true);
+    currentItem = m_configProject.kcfg_preview_profile->currentText();
+    m_configProject.kcfg_preview_profile->clear();
+    KConfigGroup group5(&conf, "timelinepreview");
+    values = group5.entryMap();
+    m_configProject.kcfg_preview_profile->addItem(i18n("Automatic"));
+    QMapIterator<QString, QString> l(values);
+    while (l.hasNext()) {
+        l.next();
+        if (!l.key().isEmpty()) m_configProject.kcfg_preview_profile->addItem(l.key(), l.value());
+    }
+    if (!currentItem.isEmpty()) m_configProject.kcfg_preview_profile->setCurrentIndex(m_configProject.kcfg_preview_profile->findText(currentItem));
+    m_configProject.kcfg_preview_profile->blockSignals(false);
+    QString data = m_configProject.kcfg_preview_profile->itemData(m_configProject.kcfg_preview_profile->currentIndex()).toString();
+    if (data.isEmpty()) {
+        m_configProject.previewparams->clear();
+    } else {
+        m_configProject.previewparams->setPlainText(data.section(';', 0, 0));
+    }
 
     // Load Proxy profiles
     m_configProject.kcfg_proxy_profile->blockSignals(true);
@@ -1203,15 +1211,19 @@ void KdenliveSettingsDialog::loadEncodingProfiles()
     m_configProject.kcfg_proxy_profile->clear();
     KConfigGroup group4(&conf, "proxy");
     values = group4.entryMap();
-    QMapIterator<QString, QString> l(values);
-    while (l.hasNext()) {
-        l.next();
-        if (!l.key().isEmpty()) m_configProject.kcfg_proxy_profile->addItem(l.key(), l.value());
+    QMapIterator<QString, QString> m(values);
+    while (m.hasNext()) {
+        m.next();
+        if (!m.key().isEmpty()) m_configProject.kcfg_proxy_profile->addItem(m.key(), m.value());
     }
     if (!currentItem.isEmpty()) m_configProject.kcfg_proxy_profile->setCurrentIndex(m_configProject.kcfg_proxy_profile->findText(currentItem));
     m_configProject.kcfg_proxy_profile->blockSignals(false);
-    slotUpdateProxyProfile();
-    
+    data = m_configProject.kcfg_proxy_profile->itemData(m_configProject.kcfg_proxy_profile->currentIndex()).toString();
+    if (data.isEmpty()) {
+        m_configProject.proxyparams->clear();
+    } else {
+        m_configProject.proxyparams->setPlainText(data.section(';', 0, 0));
+    }
 }
 
 void KdenliveSettingsDialog::slotUpdateDecklinkProfile(int ix)
@@ -1246,13 +1258,22 @@ void KdenliveSettingsDialog::slotUpdateGrabProfile(int ix)
 
 void KdenliveSettingsDialog::slotUpdateProxyProfile(int ix)
 {
-    if (ix == -1) ix = KdenliveSettings::v4l_profile();
+    if (ix == -1) ix = KdenliveSettings::proxy_profile();
     else ix = m_configProject.kcfg_proxy_profile->currentIndex();
     QString data = m_configProject.kcfg_proxy_profile->itemData(ix).toString();
     if (data.isEmpty()) return;
     m_configProject.proxyparams->setPlainText(data.section(';', 0, 0));
 }
 
+void KdenliveSettingsDialog::slotUpdatePreviewProfile(int ix)
+{
+    if (ix == -1) ix = KdenliveSettings::preview_profile();
+    else ix = m_configProject.kcfg_preview_profile->currentIndex();
+    QString data = m_configProject.kcfg_preview_profile->itemData(ix).toString();
+    if (data.isEmpty()) return;
+    m_configProject.previewparams->setPlainText(data.section(';', 0, 0));
+}
+
 void KdenliveSettingsDialog::slotEditVideo4LinuxProfile()
 {
     QString vl4ProfilePath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/profiles/video4linux";
@@ -1274,12 +1295,9 @@ void KdenliveSettingsDialog::slotReloadBlackMagic()
     m_configSdl.kcfg_external_display->setEnabled(KdenliveSettings::decklink_device_found());
 }
 
-void KdenliveSettingsDialog::slotEditProfiles()
+void KdenliveSettingsDialog::checkProfile()
 {
-    ProfilesDialog *w = new ProfilesDialog;
-    w->exec();
-    checkProfile();
-    delete w;
+    m_pw->loadProfile(KdenliveSettings::default_profile().isEmpty() ? KdenliveSettings::current_profile() : KdenliveSettings::default_profile());
 }
 
 void KdenliveSettingsDialog::slotReloadShuttleDevices()
