@@ -69,10 +69,15 @@ KeyframeImport::KeyframeImport(ItemInfo srcInfo, ItemInfo dstInfo, QMap<QString,
     lay->addWidget(m_previewLabel);
     m_keyframeView = new KeyframeView(0, this);
     // Zone in / out
-    m_inPoint = new PositionEdit(i18n("In"), srcInfo.cropStart.frames(tc.fps()), srcInfo.cropStart.frames(tc.fps()), (srcInfo.cropStart + srcInfo.cropDuration).frames(tc.fps()), tc, this);
+    ItemInfo reference;
+    if (srcInfo.isValid())
+        reference = srcInfo;
+    else
+        reference = dstInfo;
+    m_inPoint = new PositionEdit(i18n("In"), reference.cropStart.frames(tc.fps()), reference.cropStart.frames(tc.fps()), (reference.cropStart + reference.cropDuration).frames(tc.fps()), tc, this);
     connect(m_inPoint, SIGNAL(parameterChanged(int)), this, SLOT(updateDisplay()));
     lay->addWidget(m_inPoint);
-    m_outPoint = new PositionEdit(i18n("Out"), (srcInfo.cropStart + srcInfo.cropDuration).frames(tc.fps()), srcInfo.cropStart.frames(tc.fps()), (srcInfo.cropStart + srcInfo.cropDuration).frames(tc.fps()), tc, this);
+    m_outPoint = new PositionEdit(i18n("Out"), (reference.cropStart + reference.cropDuration).frames(tc.fps()), reference.cropStart.frames(tc.fps()), (reference.cropStart + reference.cropDuration).frames(tc.fps()), tc, this);
     connect(m_outPoint, SIGNAL(parameterChanged(int)), this, SLOT(updateDisplay()));
     lay->addWidget(m_outPoint);
 
@@ -100,6 +105,9 @@ KeyframeImport::KeyframeImport(ItemInfo srcInfo, ItemInfo dstInfo, QMap<QString,
         m_sourceCombo->insertItem(ix, i18n("Geometry"));
         m_sourceCombo->setItemData(ix, QString::number(10), Qt::UserRole);
         ix++;
+        m_sourceCombo->insertItem(ix, i18n("Position"));
+        m_sourceCombo->setItemData(ix, QString::number(11), Qt::UserRole);
+        ix++;
     }
     if (!m_simpleTargets.isEmpty()) {
         m_sourceCombo->insertItem(ix, i18n("X"));
@@ -207,6 +215,20 @@ void KeyframeImport::updateDataDisplay()
 {
     QString data = m_dataCombo->currentData().toString();
     m_maximas = m_keyframeView->loadKeyframes(data);
+    double wDist = m_maximas.at(2).y() - m_maximas.at(2).x();
+    double hDist = m_maximas.at(3).y() - m_maximas.at(3).x();
+    if (wDist == 0 && hDist == 0) {
+        // Source data has only x/y pos, no width/height so disable geometry import
+        int pos = m_sourceCombo->currentData().toInt();
+        int ix = m_sourceCombo->findData(10);
+        if (ix > -1)
+            m_sourceCombo->removeItem(ix);
+        if (pos == 10) {
+            ix = m_sourceCombo->findData(11);
+            if (ix > -1)
+                m_sourceCombo->setCurrentIndex(ix);
+        }
+    }
     updateRange();
     if (!m_inPoint->isValid()) {
         m_inPoint->blockSignals(true);
@@ -381,7 +403,8 @@ QString KeyframeImport::selectedData() const
         return m_keyframeView->getSingleAnimation(ix, m_inPoint->getPosition(), m_outPoint->getPosition(), m_offsetPoint->getPosition(), m_limitKeyframes->isChecked() ? m_limitNumber->value() : 0, maximas, m_destMin.value(), m_destMax.value());
     }
     // Geometry target
-    return m_keyframeView->getOffsetAnimation(m_inPoint->getPosition(), m_outPoint->getPosition(), m_offsetPoint->getPosition(), m_limitKeyframes->isChecked() ? m_limitNumber->value() : 0, m_profile, m_supportsAnim);
+    int pos = m_sourceCombo->currentData().toInt();
+    return m_keyframeView->getOffsetAnimation(m_inPoint->getPosition(), m_outPoint->getPosition(), m_offsetPoint->getPosition(), m_limitKeyframes->isChecked() ? m_limitNumber->value() : 0, m_profile, m_supportsAnim, pos == 11);
 }
 
 QString KeyframeImport::selectedTarget() const
