@@ -100,7 +100,6 @@ protected:
     void mouseReleaseEvent(QMouseEvent * event);
     void mouseDoubleClickEvent(QMouseEvent * event);
     void wheelEvent(QWheelEvent * event);
-    void showEvent(QShowEvent * event);
 
 public slots:
     void setZoom(float zoom);
@@ -227,8 +226,6 @@ signals:
     void textureReady(GLuint yName, GLuint uName = 0, GLuint vName = 0);
     void frameDisplayed(const SharedFrame& frame);
     void audioSamplesSignal(const audioShortVector&,int,int,int);
-    void audioLevels(const QVector<double>&);
-    void processFFt();
 
 private:
     QSemaphore m_semaphore;
