@@ -27,6 +27,7 @@
 #include "ui_projectsettings_ui.h"
 
 class KdenliveDoc;
+class ProfileWidget;
 
 class ProjectSettings : public QDialog, public Ui::ProjectSettings_UI
 {
@@ -49,49 +50,53 @@ public:
     const QMap <QString, QString> metadata() const;
     static QStringList extractPlaylistUrls(const QString &path);
     static QStringList extractSlideshowUrls(const QUrl &url);
+    const QString selectedPreview() const;
 
 public slots:
     virtual void accept();
 
 private slots:
-    void slotUpdateDisplay();
     void slotUpdateButton(const QString &path);
     void slotUpdateFiles(bool cacheOnly = false);
-    void slotClearCache();
-    void slotDeleteProxies();
     void slotDeleteUnused();
     /** @brief Export project data to text file. */
     void slotExportToText();
     /** @brief Update the displayed proxy parameters when user changes selection. */
     void slotUpdateProxyParams();
+    void slotUpdatePreviewParams();
     /** @brief Insert a new metadata field. */
     void slotAddMetadataField();
     /** @brief Delete current metadata field. */
     void slotDeleteMetadataField();
-    /** @brief Open project profile management dialog. */
-    void slotEditProfiles();
     /** @brief Display proxy profiles management dialog. */
     void slotManageEncodingProfile();
+    void slotManagePreviewProfile();
     /** @brief Open editor for metadata item. */
     void slotEditMetadata(QTreeWidgetItem *, int );
 
 private:
     QPushButton *m_buttonOk;
+    ProfileWidget *m_pw;
     bool m_savedProject;
     QStringList m_lumas;
-    void loadProfiles();
     QString m_proxyparameters;
     QString m_proxyextension;
     /** @brief List of all proxies urls in this project. */
     QStringList m_projectProxies;
     /** @brief List of all thumbnails used in this project. */
     QStringList m_projectThumbs;
+    QDir m_previewDir;
     /** @brief Fill the proxy profiles combobox. */
     void loadProxyProfiles();
+    QString m_previewparams;
+    QString m_previewextension;
+    /** @brief Fill the proxy profiles combobox. */
+    void loadPreviewProfiles();
 
 signals:
     /** @brief User deleted proxies, so disable them in project. */
     void disableProxies();
+    void disablePreview();
     void refreshProfiles();
 };
 
