@@ -157,7 +157,7 @@ void Clip::disableEffects(bool disable)
     }
 }
 
-QByteArray Clip::xml()
+const QByteArray Clip::xml()
 {
     Mlt::Consumer c(*m_producer.profile(), "xml", "string");
     Mlt::Service s(m_producer.get_service());
@@ -174,7 +174,8 @@ QByteArray Clip::xml()
 }
 
 Mlt::Producer *Clip::clone() {
-    return new Mlt::Producer(*m_producer.profile(), "xml-string", xml().constData());
+    Mlt::Producer *prod = new Mlt::Producer(*m_producer.profile(), "xml-string", xml().constData());
+    return prod;
 }
 
 Mlt::Producer *Clip::softClone(const char*list) {
