@@ -1627,9 +1627,19 @@ void ClipItem::dropEvent(QGraphicsSceneDragDropEvent * event)
             // Transition drop
             effects = QString::fromUtf8(event->mimeData()->data(QStringLiteral("kdenlive/transitionslist")));
             transitionDrop = true;
-        } else {
+        } else if (event->mimeData()->hasFormat(QStringLiteral("kdenlive/effectslist"))) {
             // Effect drop
             effects = QString::fromUtf8(event->mimeData()->data(QStringLiteral("kdenlive/effectslist")));
+        } else if (event->mimeData()->hasFormat(QStringLiteral("kdenlive/geometry"))) {
+            if (m_selectionTimer.isActive())
+                m_selectionTimer.stop();
+            event->acceptProposedAction();
+            CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views().first());
+            if (view) {
+                QString geometry = QString::fromUtf8(event->mimeData()->data(QStringLiteral("kdenlive/geometry")));
+                view->dropClipGeometry(this, geometry);
+            }
+            return;
         }
         event->acceptProposedAction();
         QDomDocument doc;
@@ -1944,7 +1954,7 @@ void ClipItem::updateState(const QString &id, int aIndex, int vIndex, PlaylistSt
         m_clipState = PlaylistState::Original;
 
         if (id.startsWith(QLatin1String("slowmotion"))) {
-            m_clipState = (PlaylistState::ClipState) id.section(":", -1).toInt();
+            m_clipState = id.count(QLatin1Char(':')) == 4 ? (PlaylistState::ClipState) id.section(":", -1).toInt() : PlaylistState::Original;
             return;
         }
         if (id.endsWith(QLatin1String("_audio"))) {
