@@ -105,7 +105,7 @@ public:
     void cutSelectedClips(QList<QGraphicsItem *> itemList = QList<QGraphicsItem *>(), GenTime currentPos = GenTime());
     void setContextMenu(QMenu *timeline, QMenu *clip, QMenu *transition, QActionGroup *clipTypeGroup, QMenu *markermenu);
     bool checkTrackHeight(bool force = false);
-    void updateSceneFrameWidth(bool fpsChanged = false);
+    void updateSceneFrameWidth(double fpsChanged = 1.0);
     void setTool(ProjectTool tool);
     void cutClip(const ItemInfo &info, const GenTime &cutTime, bool cut, const EffectsList &oldStack = EffectsList(), bool execute = true);
     Transition *cutTransition(const ItemInfo &info, const GenTime &cutTime, bool cut, const QDomElement &oldStack = QDomElement(), bool execute = true);
@@ -258,7 +258,10 @@ public:
     /** @brief Creates an overlay track with filtered clip */
     bool createSplitOverlay(Mlt::Filter *filter);
     void removeSplitOverlay();
+    /** @brief Geometry keyframes dropped on a transition, start import */
     void dropTransitionGeometry(Transition *trans, const QString &geometry);
+    /** @brief Geometry keyframes dropped on a clip, start import */
+    void dropClipGeometry(ClipItem *trans, const QString &geometry);
     /** @brief Switch current track lock state */
     void switchTrackLock();
     void switchAllTrackLock();
@@ -592,7 +595,7 @@ signals:
     /** @brief A clip was selected in timeline, update the effect stack
      *  @param clip The clip
      *  @param raise If true, the effect stack widget will be raised (come to front). */
-    void clipItemSelected(ClipItem *clip, bool reloadStack = true, bool raise = true);
+    void clipItemSelected(ClipItem *clip, bool reloadStack = true);
     void transitionItemSelected(Transition*, int track = 0, QPoint p = QPoint(), bool update = false);
     void activateDocumentMonitor();
     void tracksChanged();
